==> haskell-xml-hamlet-0.5.0.2-356.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-2KTLpwvDYWSLIso6bA6KXK
key:                  xml-hamlet-0.5.0.2-2KTLpwvDYWSLIso6bA6KXK
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  9eae790efef575fcc4dc9efb76dc0d6c
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xml-hamlet-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-2KTLpwvDYWSLIso6bA6KXK
depends:
    base-4.18.2.1 containers-0.6.7 parsec-3.1.16.1
    shakespeare-2.1.7-ApGKvgcgjcbHs7XYUEyo0A template-haskell-2.20.0.0
    text-2.0.2 xml-conduit-1.9.1.4-1cCl4mnX5as2ZihXQ5w8FO

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.5.0.2-358-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-2sNf5wgkEygI6aAvX2PsOk
key:                  xml-hamlet-0.5.0.2-2sNf5wgkEygI6aAvX2PsOk
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  54e3fe4c8c6981afbe664cf440910858
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xml-hamlet-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-2sNf5wgkEygI6aAvX2PsOk
depends:
    base-4.18.2.1 containers-0.6.7 parsec-3.1.16.1
    shakespeare-2.1.7-EQa3S9NEyAK816psNg58s0 template-haskell-2.20.0.0
    text-2.0.2 xml-conduit-1.9.1.4-AWUHrHEyod1C1UJeqVfDQt

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
